pub struct DeviceConfig { /* private fields */ }Expand description
DeviceConfig is used to change the device configuration, like temperature set point
Implementations
Sourceimpl DeviceConfig
impl DeviceConfig
Sourcepub fn set_mode(self, mode: DeviceMode) -> Self
pub fn set_mode(self, mode: DeviceMode) -> Self
set the mode for the set command
Sourcepub fn set_temperature(self, temperature: f64) -> Self
pub fn set_temperature(self, temperature: f64) -> Self
set the temperature set point for the set command
Sourcepub fn set_address(self, rf_address: u32) -> Self
pub fn set_address(self, rf_address: u32) -> Self
set the RF address for the set command
Sourcepub fn set_room_id(self, room_id: u8) -> Self
pub fn set_room_id(self, room_id: u8) -> Self
set the room id for the set command If the roomt id is 0, the configuration will be applied on all devices